Struct Hash

pub struct Hash(/* private fields */);
Output of the SHA-1 hash function.

Implementations

Source

impl Hash

pub const LEN: usize = 20usize

Length of the hash, in bytes.

pub fn hash(bytes: &[u8]) -> Self

Creates a default hash engine, adds bytes to it, then finalizes the engine.

Returns

The digest created by hashing bytes with engine’s hashing algorithm.

pub fn engine() -> Engine

Returns a hash engine that is ready to be used for data.

pub fn from_engine(engine: Engine) -> Self

Creates a Hash from an engine.

This is equivalent to calling Hash::from_byte_array(engine.finalize()).

pub fn from_bytes_ref(bytes: &[u8; 20]) -> &Self

Zero cost conversion between a fixed length byte array shared reference and a shared reference to this Hash type.

pub fn from_bytes_mut(bytes: &mut [u8; 20]) -> &mut Self

Zero cost conversion between a fixed length byte array exclusive reference and an exclusive reference to this Hash type.

pub fn from_slice(sl: &[u8]) -> Result<Self, FromSliceError>

Copies a byte slice into a hash object.

pub fn from_byte_array(bytes: [u8; 20]) -> Self

Constructs a hash from the underlying byte array.

pub fn to_byte_array(self) -> [u8; 20]

Returns the underlying byte array.

pub fn as_byte_array(&self) -> &[u8; 20]

Returns a reference to the underlying byte array.

pub fn as_bytes(&self) -> &[u8]

Returns a reference to the underlying byte array as a slice.

pub fn to_bytes(&self) -> Vec<u8>

Available on crate feature alloc only.

Copies the underlying bytes into a new Vec.

pub fn all_zeros() -> Self

Returns an all zero hash.

An all zeros hash is a made up construct because there is not a known input that can create it, however it is used in various places in Bitcoin e.g., the Bitcoin genesis block’s previous blockhash and the coinbase transaction’s outpoint txid.